@@ -283,6 +283,7 @@ gboolean osinfo_install_script_has_config_param_name(const OsinfoInstallScript *
 
 /**
  * osinfo_install_script_get_config_param_list:
+ * @script: the install script
  *
  * Get the list of valid config parameters for @script.
  *
@@ -297,6 +298,7 @@ GList *osinfo_install_script_get_config_param_list(const OsinfoInstallScript *sc
 
 /**
  * osinfo_install_script_get_config_params:
+ * @script: the install script
  *
  * Get the list of valid config parameters for @script.
  *
@@ -531,7 +533,7 @@ OsinfoAvatarFormat *osinfo_install_script_get_avatar_format(OsinfoInstallScript
 }
 
 struct _OsinfoInstallScriptGenerateData {
-    GSimpleAsyncResult *res;
+    GTask *res;
     OsinfoOs *os;
     OsinfoMedia *media;
     OsinfoInstallConfig *config;
@@ -551,8 +553,7 @@ static void osinfo_install_script_generate_data_free(OsinfoInstallScriptGenerate
 }
 
 struct _OsinfoInstallScriptGenerateOutputData {
-    GSimpleAsyncResult *res;
-    GCancellable *cancellable;
+    GTask *res;
     GError *error;
     GFile *file;
     GFileOutputStream *stream;
@@ -663,7 +664,7 @@ static xmlNodePtr osinfo_install_script_generate_entity_xml(OsinfoInstallScript
 {
     xmlNodePtr node = NULL;
     xmlNodePtr data = NULL;
-    GList *keys;
+    GList *keys = NULL;
     GList *tmp1;
 
     if (!(node = xmlNewDocNode(NULL, NULL, (xmlChar*)name, NULL))) {
@@ -726,6 +727,7 @@ static xmlNodePtr osinfo_install_script_generate_entity_xml(OsinfoInstallScript
     return node;
 
  error:
+    g_list_free(keys);
     xmlFreeNode(data);
     xmlFreeNode(node);
     return NULL;
@@ -808,6 +810,7 @@ static gchar *osinfo_install_script_apply_xslt(xsltStylesheetPtr ss,
                                                GError **error)
 {
     xsltTransformContextPtr ctxt;
+    xmlChar *xsltResult;
     gchar *ret = NULL;
     xmlDocPtr docOut = NULL;
     int len;
@@ -822,10 +825,12 @@ static gchar *osinfo_install_script_apply_xslt(xsltStylesheetPtr ss,
         goto cleanup;
     }
 
-    if (xsltSaveResultToString((xmlChar **)&ret, &len, docOut, ss) < 0) {
+    if (xsltSaveResultToString(&xsltResult, &len, docOut, ss) < 0) {
         g_set_error(error, 0, 0, "%s", _("Unable to convert XSL output to string"));
         goto cleanup;
     }
+    ret = g_strdup((gchar *)xsltResult);
+    xmlFree(xsltResult);
 
  cleanup:
     xmlFreeDoc(docOut);
@@ -882,7 +887,7 @@ static void osinfo_install_script_template_loaded(GObject *src,
                                      NULL,
                                      &error)) {
         g_prefix_error(&error, _("Failed to load script template %s: "), uri);
-        g_simple_async_result_take_error(data->res, error);
+        g_task_return_error(data->res, error);
         goto cleanup;
     }
 
@@ -897,15 +902,14 @@ static void osinfo_install_script_template_loaded(GObject *src,
                                               data->config,
                                               &error)) {
         g_prefix_error(&error, _("Failed to apply script template %s: "), uri);
-        g_simple_async_result_take_error(data->res, error);
+        g_task_return_error(data->res, error);
         goto cleanup;
     }
 
-    g_simple_async_result_set_op_res_gpointer(data->res,
-                                              output, NULL);
+    g_task_return_pointer(data->res, output, g_free);
 
  cleanup:
-    g_simple_async_result_complete(data->res);
+    g_free(input);
     osinfo_install_script_generate_data_free(data);
     g_free(uri);
 }
@@ -934,10 +938,10 @@ static void osinfo_install_script_generate_async_common(OsinfoInstallScript *scr
         data->media = g_object_ref(media);
     data->config = g_object_ref(config);
     data->script = g_object_ref(script);
-    data->res = g_simple_async_result_new(G_OBJECT(script),
-                                          callback,
-                                          user_data,
-                                          osinfo_install_script_generate_async_common);
+    data->res = g_task_new(G_OBJECT(script),
+                           cancellable,
+                           callback,
+                           user_data);
 
     if (templateData) {
         GError *error = NULL;
@@ -952,14 +956,11 @@ static void osinfo_install_script_generate_async_common(OsinfoInstallScript *scr
                                                   data->config,
                                                   &error)) {
             g_prefix_error(&error, "%s", _("Failed to apply script template: "));
-            g_simple_async_result_take_error(data->res, error);
-            g_simple_async_result_complete(data->res);
+            g_task_return_error(data->res, error);
             osinfo_install_script_generate_data_free(data);
             return;
         }
-        g_simple_async_result_set_op_res_gpointer(data->res,
-                                                  output, NULL);
-        g_simple_async_result_complete_in_idle(data->res);
+        g_task_return_pointer(data->res, output, g_free);
         osinfo_install_script_generate_data_free(data);
     } else {
         GFile *file = g_file_new_for_uri(templateUri);
@@ -968,6 +969,7 @@ static void osinfo_install_script_generate_async_common(OsinfoInstallScript *scr
                                    cancellable,
                                    osinfo_install_script_template_loaded,
                                    data);
+        g_object_unref(file);
     }
 }
 
@@ -1007,14 +1009,11 @@ static gpointer osinfo_install_script_generate_finish_common(OsinfoInstallScript
                                                              GAsyncResult *res,
                                                              GError **error)
 {
-    GSimpleAsyncResult *simple = G_SIMPLE_ASYNC_RESULT(res);
+    GTask *task = G_TASK(res);
 
     g_return_val_if_fail(error == NULL || *error == NULL, NULL);
 
-    if (g_simple_async_result_propagate_error(simple, error))
-        return NULL;
-
-    return g_simple_async_result_get_op_res_gpointer(simple);
+    return g_task_propagate_pointer(task, error);
 }
 
 /**
@@ -1132,9 +1131,7 @@ static void osinfo_install_script_generate_output_close_file(GObject *src,
                                  res,
                                  &data->error);
 
-    g_simple_async_result_set_op_res_gpointer(data->res,
-                                              data->file, NULL);
-    g_simple_async_result_complete_in_idle(data->res);
+    g_task_return_pointer(data->res, data->file, NULL);
 
     osinfo_install_script_generate_output_data_free(data);
 }
@@ -1231,6 +1228,8 @@ void osinfo_install_script_generate_for_media_async(OsinfoInstallScript *script,
                                                 cancellable,
                                                 callback,
                                                 user_data);
+
+    g_object_unref(os);
 }
 
 static void osinfo_install_script_generate_for_media_done(GObject *src,
@@ -1309,14 +1308,14 @@ static void osinfo_install_script_generate_output_write_file(GObject *src,
                                     data->output + data->output_pos,
                                     data->output_len - data->output_pos,
                                     G_PRIORITY_DEFAULT,
-                                    data->cancellable,
+                                    g_task_get_cancellable(data->res),
                                     osinfo_install_script_generate_output_write_file,
                                     data);
 
     } else {
         g_output_stream_close_async(G_OUTPUT_STREAM(data->stream),
                                     G_PRIORITY_DEFAULT,
-                                    data->cancellable,
+                                    g_task_get_cancellable(data->res),
                                     osinfo_install_script_generate_output_close_file,
                                     data);
     }
@@ -1338,12 +1337,11 @@ static void osinfo_install_script_generate_output_async_common(OsinfoInstallScri
 
     OsinfoInstallScriptGenerateSyncData *data_sync = user_data;
 
-    data->res = g_simple_async_result_new(G_OBJECT(script),
-                                          callback,
-                                          user_data,
-                                          osinfo_install_script_generate_output_async_common);
+    data->res = g_task_new(G_OBJECT(script),
+                           cancellable,
+                           callback,
+                           user_data);
 
-    data->cancellable = cancellable;
     data->error = data_sync->error;
     if (media != NULL) {
         data->output = osinfo_install_script_generate_for_media(script,
@@ -1653,6 +1651,7 @@ gchar *osinfo_install_script_generate_command_line_for_media(OsinfoInstallScript
             g_prefix_error(&error, "%s", _("Failed to apply script template: "));
         }
     }
+    g_object_unref(os);
 
     return output;
 }
